.streamfield_app {
    max-width: 758px;
    width: 98%;
    margin-top: 5px;
}

.streamfield_app textarea {
    display: none;
}

.streamfield_app p {
    margin-bottom: 0.5em;
}

.streamfield_app a.grp-change-related {
    background-image: none;
}
.streamfield_app a.grp-add-another {
    background-image: none;
}

.streamfield_app .stream-model-block {
    position: relative;
    background: white;
    margin-bottom: 20px;
    box-shadow: 0 0 5px 2px rgba(0,0,0,0.1);
}
.streamfield_app .stream-model-block .streamblock__block__title {
    position: relative;
}

.streamfield_app .stream-model-block .streamblock__block__title span {
    font-weight: bold;
    margin-left: 0;
}

.streamfield_app .stream-block__options {
    padding: 10px;
    text-align: right;
    background: #efefef;
}
.streamfield_app .stream-block__option {
    display: inline-block;
    margin-left: 10px;
}

.streamfield_app .stream-block__option span {
    margin: 0 0 0 5px
}

.streamfield_app .stream-block__option span + * {
    margin: 0 0 0 3px;
}

/* Block content */
.streamfield_app .stream-model-block .stream-model-block__content {
    padding: 20px;
    background: #f5f5f5;
}
.streamfield_app .stream-model-block__content .model-field-content:after {
    content: "."; 
    display: block; 
    height: 0; 
    clear: both; 
    visibility: hidden;
}

.streamfield_app .block-fields__label {
    font-style: italic;
    color: #999;
    display: block;
} 

.streamfield_app .block-fields > div {
    margin-bottom: 0.4em;
}

.streamfield_app .block-fields h2 {
    padding: 0;
    text-shadow: none;
    border: none;
    background-image: none;
    font-size: 1.3em;
} 

.streamfield_app .block-fields h3 {
    padding: 0;
    text-shadow: none;
    border: none;
    background-image: none;
    font-size: 1.1em;
    margin-bottom: 0.5em;
} 

.streamfield_app .block-fields h4 {
    font-weight: bold;
} 

.streamfield_app .block-fields blockquote {
    font-size: 1.1em;
    font-style: italic;
    font-weight: bold;
    margin-bottom: 0.4em;
} 

.streamfield_app .stream-model-block .stream-model-block__content img {
    border: 1px solid #b6b6b6;
}

.streamfield_app .block-fields table td,
.streamfield_app .block-fields table th {
    border-bottom: 1px solid #CCC;
} 

.streamfield_app .block-fields ul li {
    margin-left: 20px;
    list-style: disc;
}

.streamfield_app .block-fields ol li {
    margin-left: 20px;
    list-style: decimal;
}

.streamfield_app .block-fields b {
    font-weight: bold;
}

.streamfield_app .block-fields svg,
.streamfield_app .block-fields img
{
    max-width: 150px;
    max-height: 150px;
}

.streamfield_app .stream-model-subblock {
    background: #e0e7eb;
    padding: 10px;
    display: block;
    border-radius: 5px;
    margin-bottom: 10px;
    position: relative;
}
.streamfield_app .stream-model-block__content.no-subblocks {
    padding: 20px 28px;
}

.streamfield_app .stream-btn {
    background: #78adbf;
    color: white;
    padding: 3px 7px;
    display: inline-block;
    border-radius: 2px;
    margin-top: 5px;
    font-weight: bold;
    user-select: none;
}

.streamfield_app .stream-btn:hover {
    background: #309bbf;
}

.streamfield_app .add-another {
    margin-left: 10px;
}

.streamfield_app .stream-model-block__content.abstract-block a img {
    border: 3px solid #a6d1e0;
}
.streamfield_app .stream-model-block__content.abstract-block a:hover img {
    border-color: #78adbf;   
}


/* add new block */
.streamfield_app .stream-insert-new-block {
    text-align: right;
}
.streamfield_app .add-new-block-button {
    padding: 5px;
    font-weight: bold;
    text-decoration: underline;
    cursor: pointer;
    color: #309bbf;
    user-select: none;
}

/* Help text */
.stream-help-text {
    margin-bottom: 10px;
}
.stream-help-text .stream-help-text__title {
    padding: 5px;
    text-align: right;
    font-weight: bold;
    text-decoration: underline;
    cursor: pointer;
}
.stream-help-text .stream-help-text__content {
    padding: 10px;
    background: #d4e6d7;
    font-size: 15px;
    line-height: 1.2em;
    border-radius: 5px;
}

.stream-help-text .stream-help-text__content ul li {
    list-style: disc;
    margin: .5em 20px;
}


/* Handle */
.streamblock__block-handle,
.stream-model-subblock-handle {
    position: absolute;
    right: 2px;
    top: 1px;
}
.streamblock__block-handle .block-move,
.stream-model-subblock .subblock-move,
.streamblock__block-handle .block-delete,
.stream-model-subblock .subblock-delete {
    position: relative;
    width: 24px;
    height: 24px;
    background-image: url('data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABgAAACvBAMAAAAVlgMGAAAAGFBMVEUAAABCQkIwnL+/MDBBQUFDQ0Mwm7+/MDC6BnJcAAAABXRSTlMAn5+foPEIPbMAAACVSURBVEjH7ZQxCgIxEEV/dhHbNPbBYuvtvIAH0MILbGEteH+QGUKegTRbZsmr8nnDn1SjA3KKUnjkEJ7SJcqxl+WiTBSFIDDWKKCapYO+Oa/S/Mlh/kq3VY69LBdloigEgbFGAdUsHXRIiDvPRs3dyeHlVH7v4QpRg16YkmDZhNiWhEgT6p+rk8PbUQMKqGZp/Z0j8gNoghnFfJszcgAAAABJRU5ErkJggg==');
    background-repeat: no-repeat;
    display: block;
    margin-left: 0;
    float: left;
    cursor: pointer;
}
.streamblock__block-handle .block-delete,
.stream-model-subblock .subblock-delete {
    background-position: 0 -9px;
}
.streamblock__block-handle .block-delete:hover,
.stream-model-subblock .subblock-delete:hover {
    background-position: 0 -53px;
}
.streamblock__block-handle .block-move,
.stream-model-subblock .subblock-move {
    background-position: 0 -97px;
}
.streamblock__block-handle .block-move:hover,
.stream-model-subblock .subblock-move:hover {
    background-position: 0 -141px;
}

[v-cloak] {
    display: none;
}

/* for django skin */
#content-main .streamfield_app .stream-model-block .streamblock__block__title {
    background: #a9c8d5;
    color: black;
    margin: 0;
    padding: 0 10px;
    line-height: 32px;
    font-weight: normal;
}
#content-main .streamblock__block-handle,
#content-main .stream-model-subblock-handle {
    top: 4px;
}
#content-main .streamfield_app .stream-insert-new-block {
    font-size: 15px;
}
#content-main .streamfield_app .stream-btn {
    font-weight: normal;
}
#content-main .streamfield_app .stream-help-text ul {
    margin-left: 0;
}
